@@ -63,9 +63,9 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
     btnConfigure->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
     btnConfigure->setAutoDefault(false);
 
-    QPushButton *btnReselectDevice = dlgButtonBoxBottom->addButton(i18n("Reselect scanner device"), QDialogButtonBox::ButtonRole::ActionRole);
-    btnReselectDevice->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
-    btnReselectDevice->setAutoDefault(false);
+    m_btnReselectDevice = dlgButtonBoxBottom->addButton(i18n("Reselect scanner device"), QDialogButtonBox::ButtonRole::ActionRole);
+    m_btnReselectDevice->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
+    m_btnReselectDevice->setAutoDefault(false);
 
     m_firstImage = true;
 
@@ -73,10 +73,16 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
     connect(m_ksanew, &KSaneWidget::scannedImageReady, this, &Skanlite::imageReady);
     connect(m_ksanew, &KSaneWidget::userMessage, this, &Skanlite::alertUser);
     connect(m_ksanew, &KSaneWidget::buttonPressed, this, &Skanlite::buttonPressed);
+    connect(m_ksanew, &KSaneWidget::scanProgress, this, [this](int percent){
+        if (percent < 100) {
+            m_btnReselectDevice->setEnabled(false);
+        }
+    });
     connect(m_ksanew, &KSaneWidget::scanDone, this, [this](){
         if (!m_pendingApplyScanOpts.isEmpty()) {
             applyScannerOptions(m_pendingApplyScanOpts);
         }
+        m_btnReselectDevice->setEnabled(true);
     });
 
     m_saveProgressBar = new QProgressBar(this);
@@ -115,7 +121,7 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
     connect(this, &QDialog::finished, this, &Skanlite::saveScannerDevice);
     connect(this, &QDialog::finished, this, &Skanlite::saveScannerOptions);
     connect(btnConfigure, &QPushButton::clicked, this, &Skanlite::showSettingsDialog);
-    connect(btnReselectDevice, &QPushButton::clicked, this, &Skanlite::reselectScannerDevice);
+    connect(m_btnReselectDevice, &QPushButton::clicked, this, &Skanlite::reselectScannerDevice);
     connect(dlgButtonBoxBottom, &QDialogButtonBox::helpRequested, this, &Skanlite::showHelp);
 
     //
